| Copyright | Will Thompson, Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Pango.Structs.AttrFontDesc
Contents
Description
The #PangoAttrFontDesc structure is used to store an attribute that sets all aspects of the font description at once.
Exported types
newtype AttrFontDesc Source
Constructors
| AttrFontDesc (ForeignPtr AttrFontDesc) |
Instances
| ((~) * info (ResolveAttrFontDescMethod t AttrFontDesc), MethodInfo * info AttrFontDesc p) => IsLabel t (AttrFontDesc -> p) Source | |
| ((~) * info (ResolveAttrFontDescMethod t AttrFontDesc), MethodInfo * info AttrFontDesc p) => IsLabelProxy t (AttrFontDesc -> p) Source | |
newZeroAttrFontDesc :: MonadIO m => m AttrFontDesc Source
Construct a AttrFontDesc struct initialized to zero.