| Copyright | Will Thompson, Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Pango.Structs.Rectangle
Description
The #PangoRectangle structure represents a rectangle. It is frequently used to represent the logical or ink extents of a single glyph or section of text. (See, for instance, pango_font_get_glyph_extents())
- newtype Rectangle = Rectangle (ForeignPtr Rectangle)
- newZeroRectangle :: MonadIO m => m Rectangle
- noRectangle :: Maybe Rectangle
- rectangleReadHeight :: Rectangle -> IO Int32
- rectangleReadWidth :: Rectangle -> IO Int32
- rectangleReadX :: Rectangle -> IO Int32
- rectangleReadY :: Rectangle -> IO Int32
Exported types
Constructors
| Rectangle (ForeignPtr Rectangle) |
newZeroRectangle :: MonadIO m => m Rectangle Source
Construct a Rectangle struct initialized to zero.
Properties
Height
Width
rectangleReadWidth :: Rectangle -> IO Int32 Source
X
rectangleReadX :: Rectangle -> IO Int32 Source
Y
rectangleReadY :: Rectangle -> IO Int32 Source